Crate bb_config

Crate bb_config 

Introduction

BeagleBoard.org maintains a json file with the list of all board images which can be used by applications (like BeagleBoard Imaging Utility) to get a list of latest images for each board.

This crate provides abstractions to parse and generate distros.json file.

Usage

let config: bb_config::Config = reqwest::blocking::get(bb_config::DISTROS_URL)
    .unwrap()
    .json()
    .unwrap();

// Convert back to JSON
let json_config = serde_json::to_string_pretty(&config).unwrap();

Re-exports

pub use config::Config;

Modules

config
Abstractions to parse and generate distros.json file.

Constants

DISTROS_URL
URL for the BeagleBoard.org distros.json file