Module config

Module config 

Abstractions to parse and generate distros.json file.

Structs

Config
BeagleBoard.org distros.json abstraction.
Device
Structure describing BeagleBoard.org board
Imager
Contains information regarding BeagleBoard Images version and a list of BeagleBoard.org boards along with information regarding each board.
OsImage
A singular Os Image for board(s)
OsRemoteSubList
Sublists stored in a remote location
OsSubList
OsListItem which itself can contain a list of OsListItem.

Enums

Flasher
Types of flashers Os Image(s) support
OsListItem
Os List can contain multiple types of items depending on the situation.