pub enum OsListItem {
Image(OsImage),
SubList(OsSubList),
RemoteSubList(OsRemoteSubList),
}Expand description
Os List can contain multiple types of items depending on the situation.
Variants
Image(OsImage)
Single Os Image
SubList(OsSubList)
SubList which itself can contain a list of OsListItem.
This is used to define Testing and other images which do not need to be present at the top level.
RemoteSubList(OsRemoteSubList)
SubList stored in a remote location.
This is used to define images managed/hosted outside of the normal BeagleBoard.org image infrastructure, such as from CI, etc.
Implementations
Sourceimpl OsListItem
impl OsListItem