pub struct OsSubList {
pub name: String,
pub description: String,
pub icon: Url,
pub flasher: Flasher,
pub subitems: Vec<OsListItem>,
}Expand description
OsListItem which itself can contain a list of OsListItem.
Fields
name: StringSublist name
description: StringSublist description
icon: UrlSublist icon URL
flasher: FlasherFlasher type for all top level Os Images in the sublist
subitems: Vec<OsListItem>List of items