pub struct Config {
pub imager: Imager,
pub os_list: Vec<OsListItem>,
}Expand description
BeagleBoard.org distros.json abstraction.
Merging Behaviour
Configs can be merged together using Extend::extend. This allows for having some portion of config locally while downloading parts from network.
If Imager::latest_version is present, it will overwrite the current field.
For Imager::devices, any new board will be appended to the end of the board list. Existing boards are not added again. Duplicate boards are checked by Device::name field. The Device fields are overwritten.
For Config::os_list, all non-duplicate OsListItem are appended to the end of the list.
Fields
imager: Imageros_list: Vec<OsListItem>List of OS images for the boards